coop-tag
===============================================
Add-on for django-coop for managing tags with django-taggit, adding URI and language fields for proper export following the CommonTag RDF vocabulary.

License
=======
coop-tag uses the same license as Django (BSD).
coop-tag development was funded by `CREDIS <http://credis.org/>`_, FSE (European Social Fund) and Conseil Regional d'Auvergne.
